@@ -2,31 +2,36 @@ from metacity.datamodel.grid import Grid
 from metacity.datamodel.object import Object
 from metacity.datamodel.set import ObjectSet
 from metacity.filesystem import layer as fs
-from metacity.utils.bbox import bboxes_bbox
 from metacity.utils.persistable import Persistable
-from tqdm import tqdm
 
 
 class Layer(Persistable):
-    def __init__(self, layer_dir: str, group_by = 100000, load_set=True):
+    def __init__(self, layer_dir: str, group_by = 100000, load_set=True, load_meta=True, load_model=True):
         super().__init__(fs.layer_config(layer_dir))
 
         self.dir = layer_dir
         self.size = 0
         self.group_by = group_by
+        self.disabled = False
 
-        fs.create_layer(layer_dir)
+        fs.create_layer(self.dir)
+        self.load_meta = load_meta
+        self.load_model = load_model
 
         try:
             self.load()
-        except IOError:
+        except FileNotFoundError:
             self.export()
 
         if load_set:
-            self.set = ObjectSet(self.dir, 0, self.group_by)
+            self.set = ObjectSet(self.dir, 0, self.group_by, load_meta=load_meta, load_model=load_model)
         else:
             self.set = None
     
+    @property
+    def type(self):
+        return "layer"
+
     @property
     def name(self):
         return fs.layer_name(self.dir)
@@ -55,14 +60,14 @@ class Layer(Persistable):
 
     def activate_set(self, index):
         offset = (index // self.group_by) * self.group_by
-        self.set = ObjectSet(self.dir, offset, self.group_by)
+        self.set = ObjectSet(self.dir, offset, self.group_by, load_meta=self.load_meta, load_model=self.load_model)
 
     def regroup(self, group_by):
         tmp = fs.layer_regrouped(self.dir)
         fs.remove(tmp)
 
         regrouped = Layer(tmp, group_by)
-        for o in tqdm(self.objects):
+        for o in self.objects:
             regrouped.add(o)
 
         regrouped.persist()
@@ -70,7 +75,6 @@ class Layer(Persistable):
         self.group_by = group_by
         self.export()
 
-
     @property
     def objects(self):
         for i in range(self.size):
@@ -82,7 +86,7 @@ class Layer(Persistable):
     def build_grid(self):
         grid = Grid(self.dir)
         grid.clear()
-        for oid, object in tqdm(enumerate(self.objects)):
+        for oid, object in enumerate(self.objects):
             for model in object.models:
                 grid.add(oid, model) 
         return grid
@@ -91,27 +95,31 @@ class Layer(Persistable):
         return {
             'type': 'layer',
             'size': self.size,
-            'group_by': self.group_by
+            'group_by': self.group_by,
+            'disabled': self.disabled
         }
 
     def deserialize(self, data):
         self.size = data['size']
         self.group_by = data['group_by']
+        self.disabled = data['disabled']
 
     def build_layout(self):
         grid = self.grid
-        if grid.init:
+        if grid.init and not self.disabled:
             return {
                 'name': self.name,
                 'layout': grid.build_layout(),
                 'size': self.size,
-                'init': True,
+                'init': grid.init,
+                'disabled': self.disabled,
                 'type': 'layer'
             }
         else:
             return {
                 'name': self.name,
-                'init': False,
+                'init': grid.init,
+                'disabled': self.disabled,
                 'type': 'layer'
             }
 
@@ -122,13 +130,20 @@ class LayerOverlay(Persistable):
         self.source_layer = None
         self.target_layer = None
         self.dir = overlay_dir
-        fs.create_overlay(overlay_dir)
+        self.disabled = False
+        self.size_source = 0
+        self.size_target = 0
+        fs.create_overlay(self.dir)
 
         try:
             self.load()
-        except IOError:
+        except FileNotFoundError:
             self.export()
 
+    @property
+    def type(self):
+        return "overlay"
+
     @property
     def grid(self):
         return Grid(self.dir)
@@ -137,24 +152,39 @@ class LayerOverlay(Persistable):
     def name(self):
         return fs.layer_name(self.dir)
 
-    def setup(self, source: Layer, target: Layer):
+    @property
+    def size(self):
+        return [self.size_source, self.size_target]
+
+    def setup(self, source: Layer, target: Layer, iterationCallback=None):
+        if source.type != "layer" or target.type != "layer":
+            raise Exception(f"Cannot map type {source.type} to {target.type}, only layer to layer is supported")
+
         tg = target.grid
         sg = source.grid
 
         grid = self.grid
 
+        it = 0
         for source_tile, target_tile in sg.overlay(tg):
             pol = target_tile.polygon
             if pol is None:
                 continue
+            
             for source_model in source_tile.objects:
                 source_copy = source_model.copy()
                 source_copy.map(pol)
                 grid.tile_from_single_model(source_copy, source_tile.name)
 
+            if iterationCallback is not None:
+                iterationCallback(it)
+                it += 1
+
         grid.persist() #persist with empy cache
         self.source_layer = source.name
         self.target_layer = target.name
+        self.size_source = source.size
+        self.size_target = target.size
 
     def persist(self):
         self.export()
@@ -162,23 +192,31 @@ class LayerOverlay(Persistable):
     def serialize(self):
         return {
             'type': 'overlay',
+            'disabled': self.disabled,
             'source': self.source_layer,
-            'target': self.target_layer
+            'target': self.target_layer,
+            'size_source': self.size_source,
+            'size_target': self.size_target
         }
 
     def deserialize(self, data):
         self.source_layer = data['source']
         self.target_layer = data['target']
+        self.disabled = data['disabled']
+        self.size_source = data['size_source']
+        self.size_target = data['size_target']
 
     def build_layout(self):
         grid = self.grid
-        if grid.init:
+        if grid.init and not self.disabled:
             return {
                 'name': self.name,
                 'source': self.source_layer,
                 'target': self.target_layer,
+                'size': self.size,
                 'layout': grid.build_layout(),
-                'init': True,
+                'init': grid.init,
+                'disabled': self.disabled,
                 'type': 'overlay'
             }
         else:
@@ -186,7 +224,9 @@ class LayerOverlay(Persistable):
                 'name': self.name,
                 'source': self.source_layer,
                 'target': self.target_layer,
-                'init': False,
+                'size': self.size,
+                'init': grid.init,
+                'disabled': self.disabled,
                 'type': 'overlay'
             }
 
